function out=model_c(flag,s,x,rho,gamma,psi,alpha,delta,sigma,eta,kappa,omega)

% out=model_c(flag, s, x, rho, gamma, psi, alpha, delta, sigma, eta, A): 
% defines the objective, drift and diffusion functions of the model.
% Inputs:
% flag   : Defines which component to evaluate
%           f    : Objective function (in terms of consumption)
%           g    : Drift function
%           sigma: Diffusion function
%           rho  : discount factor
%           param: other user defined parameters
% s      : State variables (deviations from the steady state)
% x      : Control variables (deviations from the steady state)
% The remaining inputs are the parameters of the model. 
% Output:
% out    : Value of function chosen by the user to be evaluated
%
%  Author: Juan Carlos Parra-Alvarez
%  Aarhus University
%  September 2013

n=size(s,1);

switch flag
    case 'f'
            out = ((x(:,1).*(1-x(:,2)).^psi).^(1-gamma))/(1-gamma);
    case 'g'
            out = [s(:,2).*s(:,1).^alpha.*x(:,2).^(1-alpha) - delta*s(:,1) - x(:,1), kappa*(omega-s(:,2))];
    case 'sigma'
        if eta==0 && sigma==0
            out = [];
        else
            out = [sigma*s(:,1), zeros(n,2), eta*sqrt(s(:,2))];
        end
    case 'rho'
        out = rho+zeros(n,1);
    case 'param'
        out = [];        
end


