function out=ss_bench(X)

% function out=ss_bench(X): 
% System of equations that defines the steady state system of the full 
% model without parametric restrictions
% Function used by the files SteadyState.m
% Takes as input (X) a vector of initial values for the variables of the
% model, and gives as output (out) the steady state values of the variables
%
%  Author: Juan Carlos Parra-Alvarez
%  Aarhus University
%  September 2013

%% ---------------------------------------------------------------------- %
%                               Parameters                                %
%-------------------------------------------------------------------------%
global gamma psi delta rho alpha kappa omega;

A  = X(1);
k  = X(2);
l  = X(3);
c  = X(4);
v  = X(5);
vk = X(6);
vA = X(7);
r  = X(8);
w  = X(9);

%% ---------------------------------------------------------------------- %
%                         System of Equations                             %
%-------------------------------------------------------------------------%
out = [(r-delta)*k + w*l- c;
       kappa*(omega-A);
       ((c*(1-l)^psi)^(1-gamma))/(1-gamma) - rho*v;
       c^(-gamma)*(1-l)^(psi*(1-gamma)) - vk;
       psi*c^(1-gamma)*(1-l)^(psi*(1-gamma)-1) - w*vk;
       r - alpha*A*k^(alpha-1)*l^(1-alpha);
       w - (1-alpha)*A*k^alpha*l^(-alpha);
       (r-delta)*vk - rho*vk;
       k^(alpha)*l^(1-alpha)*vk - kappa*vA - rho*vA];

end