function out=ss_closed(X)

% function out=ss_closed(X): 
% System of equations that defines the steady state system of model 
% under prop. 3.2.
% Function used by the files SteadyStateClosed.m
% Takes as input (X) a vector of initial values for the variables of the
% model, and gives as output (out) the steady state values of the variables
%
%  Author: Juan Carlos Parra-Alvarez
%  Aarhus University
%  September 2013

%% ---------------------------------------------------------------------- %
%                               Parameters                                %
%-------------------------------------------------------------------------%
global gamma psi delta rho alpha A;

k  = X(1);
l  = X(2);
c  = X(3);
v  = X(4);
vk = X(5);
r  = X(6);
w  = X(7);

%% ---------------------------------------------------------------------- %
%                         System of Equations                             %
%-------------------------------------------------------------------------%
out = [(r-delta)*k + w*l- c;
       ((c*(1-l)^psi)^(1-gamma))/(1-gamma) - rho*v;
       c^(-gamma)*(1-l)^(psi*(1-gamma)) - vk;
       psi*c^(1-gamma)*(1-l)^(psi*(1-gamma)-1) - w*vk;
       r - alpha*A*k^(alpha-1)*l^(1-alpha);
       w - (1-alpha)*A*k^alpha*l^(-alpha);
       (r-delta)*vk - rho*vk];
       
end